simadb_cli

## Name

simadb_cli — simadb_cli is a command line interface editor for the sima user DB.

## Synopsis

`simadb_cli` `--remove_artist=``artist` [ `--dbfile=``db_file` ] [ `--reciprocal` ]

`simadb_cli` `--purge_hist` [ `--dbfile=``db_file` ]

`simadb_cli` `--view_all` [ `--dbfile=``db_file` ]

`simadb_cli` { `--bl_curr_trk` | `--bl_curr_art` | `--bl_curr_alb` | `--bl_art=``artist_name` } [ `--dbfile=``db_file` ] [ `--host=``mpd_host` ] [ `--port=``mpd_port` ]

`simadb_cli` `--remove_bl=``row_id` [ `--dbfile=``db_file` ]

`simadb_cli` `--view_bl` [ `--dbfile=``db_file` ]

`simadb_cli` { { `-h` | `--help` } | `--version` }

## DESCRIPTION

This manual page documents briefly the simadb_cli commands.

simadb_cli is a command line interface to get and edit users blacklist database used with MPD_sima. The default database file (see the section called “FILES”) can be overridden if you want.

## EXAMPLE

### Black list edition

Adding to black list. You can add a single track, an album or an artist to the black list. The element to black list is chosen from the currently playing track. Use `--bl_curr_trk` to prevent simadb_cli to queue this track, `--bl_curr_alb` or `--bl_curr_art` respectively for the album and the artist.

Remember you need access to your MPD server to retrieve information to black list. Defaults are localhost:6600 or found in environment variables but you may set it up from command line:

simadb_cli --bl_curr_art -S mympd.example.org

To black list a specific artist (not currently playing) you can use `--bl_ar="Artist name to black list"`.

## OPTIONS

The program follows the usual GNU command line syntax, with long options starting with two dashes ("-"). A summary of options is included below.

`-h`, `--help`

  Print help and exit.

`--version`

  Print version and exit.

`--bl_art=`artist_name``

  Use to black list `artist_name`. simadb_cli is checking `artist_name` is actually in MPD music library (cf `-S` and `-P` options to set MPD host/address if necessary).

  If `artist_name` is not found the script print out a list of matching artists.

`--bl_curr_trk` | `--bl_curr_art` | `--bl_curr_alb`

  Use to black list the currently playing track|artist|album. You need access to your MPD server, use `-S` and `-P` to set MPD host/address if necessary.

`-d `db_file``, `--dbfile=`db_file``

  Use the specific file `db_file` as database.
  Default is too use `XDG_DATA_HOME` (see the section called “FILES”).

`--purge_hist`

  Purge history, you may supply an alternative DB file with --dbfile option.

`--remove_bl=`row_id``

  Use to remove a black list entry. To get the row_id to suppress use `--view_bl` option.

`--view_bl`

  Get all entries in the black list.

`-P `mpd_port``, `--port=`mpd_port``

  Use the specific port number `mpd_port` on MPD server. This overrides `MPD_PORT` environment variable.
  Default is 6600.

`-S `mpd_host``, `--host=`mpd_host``

  Use the specific host `mpd_host` as MPD server.
  `mpd_host` can be an IP or a fully qualified domain name as long as your system can resolve it. This overrides `MPD_HOST` environment variable.
  Default is localhost.

## FILES

`${XDG_DATA_HOME}/mpd_sima/sima.db`

  SQLite DB file. Usually `XDG_DATA_HOME` is set to `${HOME}/.local/share`.

## FEEDBACK/BUGS

The maintainer would be more than happy to ear from you, don't hesitate to send feedback, http://kaliko.me/id/.

XMPP users are welcome to join the dedicated chat room at kaliko.me@conf.azylum.org.

## SEE ALSO

mpc(1), mpd(1)

`/usr/share/doc/mpd-sima/`